#
# spec file for package glusterfs
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           glusterfs
Version:        3.12.3
Release:        lp151.2.5
Summary:        Aggregating distributed file system
License:        GPL-2.0 OR LGPL-3.0+
Group:          System/Filesystems
Url:            http://www.gluster.org/
#Git-Clone:	git://github.com/gluster/glusterfs
#Git-Clone:	git://github.com/fvzwieten/lsgvt
Source:         https://download.gluster.org/pub/gluster/glusterfs/3.12/3.12.3/glusterfs-%version.tar.gz
Patch1:         glusterfs-tirpc.diff
Patch2:         0001-build-restore-ability-to-control-verbosity-settings.patch
BuildRequires:  acl-devel
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  bison
BuildRequires:  fdupes
BuildRequires:  flex
BuildRequires:  libaio-devel
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  python2
BuildRequires:  readline-devel
BuildRequires:  rpcgen
BuildRequires:  systemd-rpm-macros
BuildRequires:  pkgconfig(fuse) >= 2.6.5
BuildRequires:  pkgconfig(libcrypto)
BuildRequires:  pkgconfig(libtirpc)
BuildRequires:  pkgconfig(liburcu)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(python)
BuildRequires:  pkgconfig(sqlite3)
BuildRequires:  pkgconfig(uuid)
%{?systemd_requires}

%description
GlusterFS is a clustered file-system capable of scaling to several
petabytes. It aggregates various storage bricks over Infiniband RDMA
or TCP/IP interconnect into one large parallel network file system.
GlusterFS is one of the most sophisticated file systems in terms of
features and extensibility. It borrows a powerful concept called
Translators from GNU Hurd kernel. Much of the code in GlusterFS is in
user space and easily manageable.

%package -n libgfapi0
Summary:        GlusterFS API library
Group:          System/Libraries

%description -n libgfapi0
GlusterFS is a clustered file-system capable of scaling to several
petabytes.

%package -n libgfchangelog0
Summary:        GlusterFS volume changelog translator library
Group:          System/Libraries

%description -n libgfchangelog0
GlusterFS is a clustered file-system capable of scaling to several
petabytes.

The goal of this volume translator is to capture changes performed on
a GlusterFS volume. The translator needs to be loaded on the server
(bricks) and captures changes in a plain text file inside a
configured directory path (controlled by the "changelog-dir"
directive).

%package -n libgfrpc0
Summary:        GlusterFS Remote Procedure Call library
Group:          System/Libraries

%description -n libgfrpc0
GlusterFS is a clustered file-system capable of scaling to several
petabytes.

%package -n libgfxdr0
Summary:        GlusterFS's External Data Representation library
Group:          System/Libraries

%description -n libgfxdr0
GlusterFS is a clustered file-system capable of scaling to several
petabytes.

%package -n libglusterfs0
Summary:        GlusterFS's core library
Group:          System/Libraries

%description -n libglusterfs0
GlusterFS is a clustered file-system capable of scaling to several
petabytes.

%package -n libgfdb0
Summary:        GlusterFS's database library
Group:          System/Libraries

%description -n libgfdb0
GlusterFS is a clustered file-system capable of scaling to several
petabytes.

%package -n python-gluster
Summary:        Python bindings for GlusterFS
Group:          Development/Languages/Python

%description -n python-gluster
GlusterFS is a clustered file-system capable of scaling to several
petabytes.

%package devel
Summary:        Development files for glusterfs
Group:          Development/Libraries/C and C++
Requires:       %name = %version
Requires:       libacl-devel
Requires:       libgfapi0 = %version
Requires:       libgfchangelog0 = %version
Requires:       libgfrpc0 = %version
Requires:       libgfxdr0 = %version
Requires:       libglusterfs0 = %version

%description devel
GlusterFS is a clustered file-system capable of scaling to several
petabytes.

This package provides development files such as headers and library
links.

%prep
%setup -q
%patch -P 1 -P 2 -p1
>contrib/sunrpc/xdr_sizeof.c

%build
./autogen.sh
%configure \
    --disable-static \
    --disable-silent-rules
make %{?_smp_mflags}
find . -name 'xdr_sizeof*' -type f -exec ls -lgo {} + || :

%install
%make_install docdir="%_docdir/%name"
find %buildroot -type f -name "*.la" -delete -print

mkdir -p "%buildroot/%_localstatedir/log"/{glusterd,glusterfs,glusterfsd}

# The things seemingly forgotten by make install.
# - Manually populate devel dirs
mkdir -p "%buildroot/%_includedir/%name"
install -pm0644 libglusterfs/src/*.h "%buildroot/%_includedir/%name/"
# - hekafs wants this:
mkdir -p "%buildroot/%_includedir/%name"/{rpc,server}
install -pm0644 rpc/rpc-lib/src/*.h rpc/xdr/src/*.h \
	"%buildroot/%_includedir/%name/rpc/"
install -pm0644 xlators/protocol/server/src/*.h \
	"%buildroot/%_includedir/%name/server/"
# - wrapper umount script?
# - logrotate entry
mkdir -p "%buildroot/%_localstatedir/log/%name"
# - vim syntax

# - state
mkdir -p "%buildroot/%_localstatedir/lib/glusterd"
perl -i -pe \
	's{^(\s*option working-directory )\S+}{$1 %_localstatedir/lib/glusterd}g' \
	"%buildroot/%_sysconfdir/%name/glusterd.vol"

# Clean, but must NOT remove .la from dirs not searched by
# default, thus maxdepth.
find %buildroot -type f -name "*.la" -delete -print

# W: wrong-file-end-of-line-encoding
perl -i -pe 's{\x0d\x0a}{\x0a}gs' %_docdir/%name/glusterfs-mode.el

mkdir -p "%buildroot/%_unitdir"
ln -s service "%buildroot/%_sbindir/rcglusterd"
chmod u-s "%buildroot/%_bindir/fusermount-glusterfs"
rm -f "%buildroot/%_sbindir/conf.py"
%fdupes %buildroot/%_prefix

%pre
%service_add_pre glusterd.service glustereventsd.service glusterfssharedstorage.service

%post
%service_add_post glusterd.service glustereventsd.service glusterfssharedstorage.service

%preun
%service_del_preun glusterd.service glustereventsd.service glusterfssharedstorage.service

%postun
%service_del_postun glusterd.service glustereventsd.service glusterfssharedstorage.service

%post   -n libgfapi0 -p /sbin/ldconfig
%postun -n libgfapi0 -p /sbin/ldconfig
%post   -n libgfchangelog0 -p /sbin/ldconfig
%postun -n libgfchangelog0 -p /sbin/ldconfig
%post   -n libgfrpc0 -p /sbin/ldconfig
%postun -n libgfrpc0 -p /sbin/ldconfig
%post   -n libgfxdr0 -p /sbin/ldconfig
%postun -n libgfxdr0 -p /sbin/ldconfig
%post   -n libglusterfs0 -p /sbin/ldconfig
%postun -n libglusterfs0 -p /sbin/ldconfig
%post   -n libgfdb0 -p /sbin/ldconfig
%postun -n libgfdb0 -p /sbin/ldconfig

%files
%doc COPYING-GPLV2 COPYING-LGPLV3 ChangeLog NEWS README.md
%dir %_sysconfdir/%name
%config(noreplace) %_sysconfdir/%name/eventsconfig.json
%config(noreplace) %_sysconfdir/%name/g*lusterd.vol
%config(noreplace) %_sysconfdir/%name/glusterfs-logrotate
%config %_sysconfdir/%name/gluster-rsyslog*.conf
%config %_sysconfdir/%name/*.example
%config %_sysconfdir/%name/*-logrotate
%config %_sysconfdir/%name/group-*
%_bindir/fusermount-glusterfs
%_bindir/glusterfind
/sbin/mount.%name
%_libexecdir/%name/
%_libdir/%name/
%_sbindir/gluster*
%_sbindir/glfsheal
%_sbindir/rcglusterd
%_sbindir/gcron.py
%_sbindir/gf_attach
%_sbindir/gfind_missing_files
%_sbindir/snap_scheduler.py
%_datadir/glusterfs/
%_mandir/man*/*
%_docdir/%name
%_localstatedir/lib/glusterd
%_localstatedir/log/%name
%_unitdir/glusterd.service
%_unitdir/glustereventsd.service
%_unitdir/glusterfssharedstorage.service
%_libexecdir/ocf

%files -n libgfapi0
%_libdir/libgfapi.so.0*

%files -n libgfchangelog0
%_libdir/libgfchangelog.so.0*

%files -n libgfrpc0
%_libdir/libgfrpc.so.0*

%files -n libgfxdr0
%_libdir/libgfxdr.so.0*

%files -n libglusterfs0
%_libdir/libglusterfs.so.0*

%files -n libgfdb0
%_libdir/libgfdb.so.0*

%files -n python-gluster
%dir %python_sitelib/gluster
%dir %python_sitelib/gluster/glupy
%python_sitelib/gluster/__init__.*
%python_sitelib/gluster/cliutils/
%python_sitelib/gluster/glupy/__init__.*

%files devel
%_includedir/%name
%_libdir/*.so
%_libdir/pkgconfig/*.pc

%changelog
* Thu Dec 14 2017 jengelh@inai.de
- Add 0001-build-restore-ability-to-control-verbosity-settings.patch
- Replace xdr_sizeof.c with an empty file
* Mon Dec  4 2017 jengelh@inai.de
- Update to new release 3.12.3
  * -- Features introduced in 3.10
  * Brick multiplexing
  * Support to display op-version information from clients
  * Support for rebalance time to completion estimation
  * Separation of tier as its own service
  * Statedump support for gfapi based applications
  * Disabled creation of trash directory by default
  * Implemented parallel readdirp with distribute xlator
  * -- Features introduced in 3.12:
  * Ability to mount sub-directories using the Gluster
    FUSE protocol
  * GFID to path conversion is enabled by default
  * Provided an option to set a limit on number of bricks
    multiplexed in a processes
  * Enhanced the option to export statfs data for bricks
    sharing the same backend filesystem
  * Provided a means to resolve GFID split-brain using
    the gluster CLI
  * Introduction of new api glfs_fd_set_lkowner() to set lock owner
- Remove glusterfs-date.diff (no longer applies)
* Mon Nov 13 2017 kukuk@suse.de
- glusterfs-tirpc.diff: fallback to libtirpc if there is no sunrpc
  support in glibc
* Fri Nov  3 2017 mpluskal@suse.com
- Explicitly require python2 as python3 is not yet supported
* Wed Oct 18 2017 vcizek@suse.com
- Add missing Requires: libacl-devel to the devel subpackage
  * glfs.h #includes <sys/acl.h>
* Wed Aug 23 2017 vcizek@suse.com
- Update to version 3.8.15
  * fixes build with OpenSSL 1.1 (bsc#1055466)
  * Mandatory lock support for Multiprotocol environment
  * Gluster/NFS disabled by default
  * Geo-replication for Sharded Volumes
  * Tiering aware Geo-replication
  * Enhance Quota enable/disable in glusterd
  * Automagic unsplit-brain by [ctime|mtime|size|majority] for AFR
  * Granular Entry self-heal for AFR
  * Tons of bugfixes
  * for more details see the NEWS file
- spec cleanup
- Install License files/docu
* Tue Oct 27 2015 scorot@free.fr
- Update to version 3.6.6
  * No ChangeLog available
* Tue Aug  4 2015 scorot@free.fr
- Update to version 3.6.4
  * No ChangeLog available
- Fix Url
* Thu Apr  9 2015 afaerber@suse.de
- Update to version 3.6.2
  * glusterfs-api.pc had version 0.0.0 in v3.6.1, now 4.3.6.2
  This is still a backwards jump from v3.6.0 (7.0.0) and v3.5.3 (6).
  * Package glfsheal again
* Thu Jan 15 2015 p.drouand@gmail.com
- Update to version 3.6.1
  * api: versioned symbols in libgfapi.so for compatibility
  * Use versioned symbols to keep libgfapi at libgfapi.so.0.0.0
  * Some nits uncovered:
  - there are a couple functions declared that do not have an
    associated definition, e.g. glfs_truncate(), glfs_caller_specific_init()
  - there are seven private/internal functions used by heal/src/glfsheal
    and the gfapi master xlator (glfs-master.c): glfs_loc_touchup(),
    glfs_active_subvol(), and glfs_subvol_done(), glfs_init_done(),
    glfs_resolve_at(), glfs_free_from_ctx(), and glfs_new_from_ctx();
    which are not declared in glfs.h;
  - for this initial pass at versioned symbols, we use the earliest version
    of all public symbols, i.e. those for which there are declarations in
    glfs.h or glfs-handles.h.
    Further investigation as we do backports to 3.6, 3.4, and 3.4
    will be required to determine if older implementations need to
    be preserved (forward ported) and their associated alias(es) and
    symbol version(s) defined.
* Mon Aug  4 2014 scorot@free.fr
- Update to new upstream release 3.5.2
  * NFS server crashes in _socket_read_vectored_request
  * Can't write to quota enable folder
  * nfs: reset command does not alter the result for nfs options
    earlier set
  * features/gfid-access: stat on .gfid virtual directory return
    EINVAL
  * creating symlinks generates errors on stripe volume
  * Self-heal errors with "afr crawl failed for child 0 with ret -1"
    while performing rolling upgrade.
  * [AFR] I/O fails when one of the replica nodes go down
  * Fix inode leaks in gfid-access xlator
  * NFS subdir authentication doesn't correctly handle
    multi-(homed,protocol,etc) network addresses
  * nfs-utils should be installed as dependency while installing
    glusterfs-server
  * Excessive logging in quotad.log of the kind 'null client'
  * client_t clienttable cliententries are never expanded when all
    entries are used
  * AFR : self-heal of few files not happening when a AWS EC2 Instance
    is back online after a restart
  * Dist-geo-rep : deletion of files on master, geo-rep fails to
    propagate to slaves.
  * Allow the usage of the wildcard character '*' to the options
    "nfs.rpc-auth-allow" and "nfs.rpc-auth-reject"
  * glfsheal: Improve the way in which we check the presence of
    replica volumes
  * Resource cleanup doesn't happen for clients on servers after
    disconnect
  * mounting a volume over NFS (TCP) with MOUNT over UDP fails
  * backport 'gluster volume status --xml' issues
  * Glustershd memory usage too high
* Tue Jul 29 2014 scorot@free.fr
- Update to new upstream release 3.5.1
  * A new volume option server.manage-gids has been added.
    This option should be used when users of a volume are in more
    than approximately 93 groups (Bug 1096425).
  * Duplicate Request Cache for NFS has now been disabled by
    default, this may reduce performance for certain workloads,
    but improves the overall stability and memory footprint for
    most users.
  * Others changes are mostly bug fixes.
- disable systemd pre an post scripts for old product and then fix
  build on SLE 11
* Mon May  5 2014 jengelh@inai.de
- Update to new upstream release 3.5.0
  * AFR_CLI_enhancements: Improved logging with more clarity and
  statistical information. It allows visibility into why a
  self-heal process was initiated and which files are affected, for
  example. Prior to this enhancement, clearly identifying
  split-brain issues from the logs was often difficult, and there
  was no facility to identify which files were affected by a split
  brain issue automatically. Remediating split brain without quorum
  will still require some manual effort, but with the tools
  provided, this will become much simpler.
  * Exposing Volume Capabilities: Provides client-side insight into
  whether a volume is using the BD translator and, if so, which
  capabilities are being utilized.
  * File Snapshot: Provides a mechanism for snapshotting individual
  files. The most prevalent use case for this feature will be to
  snapshot running VMs, allowing for point-in-time capture. This
  also allows a mechanism to revert VMs to a previous state
  directly from Gluster, without needing to use external tools.
  * GFID Access: A new method for accessing data directly by GFID.
  With this method, the data can be directly consumed in changelog
  translator, which is logging ‘gfid’ internally, very efficiently.
  * On-Wire Compression + Decompression: Use of this feature reduces
  the overall network overhead for Gluster operations from a
  client.
  * Prevent NFS restart on Volume change (Part 1): Previously, any
  volume change (volume option, volume start, volume stop, volume
  delete, brick add, etc.) would restart the NFS server, which led
  to service disruptions. This feature allow modifying certain
  NFS-based volume options without such interruptions occurring.
  Part 1 is anything not requiring a graph change.
  * Quota Scalability: Massively increase the amount of quota
  configurations from a few hundred to 65536 per volume.
  * readdir_ahead: Gluster now provides read-ahead support for
  directories to improve sequential directory read performance.
  * zerofill: Enhancement to allow zeroing out of VM disk images,
  which is useful in first time provisioning or for overwriting an
  existing disk.
  * Brick Failure Detection: Detecting failures on the filesystem
  that a brick uses makes it possible to handle errors that are
  caused from outside of the Gluster environment.
  * Disk encryption: Implement the previous work done in HekaFS into
  Gluster. This allows a volume (or per-tenant part of a volume) to
  be encrypted “at rest” on the server using keys only available on
  the client. [Note: Only content of regular files is encrypted.
  File names are not encrypted! Also, encryption does not work in
  NFS mounts.]
  * Geo-Replication Enhancement: Previously, the geo-replication
  process, gsyncd, was a single point of failure as it only ran on
  one node in the cluster. If the node running gsyncd failed, the
  entire geo-replication process was offline until the issue was
  addressed. In this latest incarnation, the improvement is
  extended even further by foregoing use of xattrs to identify
  change candidates and directly consuming from the volume
  changelog, which will improve performance twofold: one, by
  keeping a running list of only those files that may need to be
  synced; and two, the changelog is maintained in memory, which
  will allow near instant access to which data needs to be changed
  and where by the gsync daemon.
* Thu Feb 28 2013 jengelh@inai.de
- Update to new upstream release 3.4.0alpha (rpm: 3.4.0~qa9)
  * automake-1.13 support
- Enable AIO support
* Tue Nov 27 2012 jengelh@inai.de
- Use `glusterd -N` in glusterd.service to run in foreground
  as required
* Tue Nov 27 2012 cfarrell@suse.com
- license update: GPL-2.0 or LGPL-3.0+
* Fri Nov  9 2012 jengelh@inai.de
- Update to new upstream release 3.4.0qa2
  * No changelog provided by upstream
- Remove glusterfs-init.diff, merged upstream
- Provide systemd service file
* Wed Oct 31 2012 jengelh@inai.de
- Update to new upstream release 3.3.1
  * mount.glusterfs: Add support for {attribute,entry}-timeout options
  * cli: Proper xml output for "gluster peer status"
  * self-heald: Fix inode leak
  * storage/posix: implement native linux AIO support
* Mon Sep 24 2012 jengelh@inai.de
- Update to new upstream release 3.3.0
  * New: Unified File & Object access
  * New: Hadoop hooks - HDFS compatibility layer
  * New volume type: Repstr - replicated + striped (+ distributed)
  volumes
* Fri Dec  2 2011 coolo@suse.com
- add automake as buildrequire to avoid implicit dependency
* Wed Oct  5 2011 jengelh@medozas.de
- Initial package for build.opensuse.org
